@@ -1,22 +1,25 @@
 
 import os
 
+from . import analysis
+from .analysis import *
+
+from . import external
+from .external import *
+
 from . import framework
 from .framework import *
 
-from . import analysis
-from . import external
-
 from . import geometry
-from . import viz
-
-from .analysis import *
-from .external import *
 from .geometry import *
+
+# from . import viz
+# from .viz import *
+
 from .io import *
 from .misc import *
 from .version import __version__
-from .viz import *
+
 
 # Contents
 __all__ = [
@@ -30,7 +33,7 @@ __all__.extend(analysis.__all__)
 __all__.extend(external.__all__)
 __all__.extend(framework.__all__)
 __all__.extend(geometry.__all__)
-__all__.extend(viz.__all__)
+# __all__.extend(viz.__all__)
 
 # Add include path
 include_dir = os.path.abspath(__file__ + '/../../include')
